@@ -61,16 +61,21 @@ def get_video_n_frame(video_path):
 
 
 def split_video(video_file_path, output_path=None,
-                start_time=None, end_time=None):
+                start_time=None, end_time=None,
+                hflip=False, vflip=False):
     if start_time is None and end_time is None:
         raise ValueError
     start_time = start_time or 0.0
     end_time = end_time or get_video_duration(video_file_path)
     command = ['ffmpeg',
                '-y',
-               '-ss', str(int(start_time)),
-               '-t', str(int(end_time - start_time)),
+               '-ss', str(start_time),
+               '-t', str(end_time - start_time),
                '-i', str(video_file_path)]
+    if hflip is True:
+        command.extend(['-vf', 'hflip'])
+    if vflip is True:
+        command.extend(['-vf', 'vflip'])
     if output_path is None:
         suffix = Path(video_file_path).suffix
         with NamedTemporaryFile(delete=True, suffix=suffix) as tmp:
